@@ -206,6 +206,9 @@ extern void glp_set_row_fctr(LPI *lp, int i, double fctr);
 extern void glp_set_row_name(LPI *lp, int i, char *name);
 /* assign (change) row name */
 
+extern void *glp_to_lpx(LPI *lpi, int all);
+/* convert LP problem instance to low-level object */
+
 struct wmps
 {     /* parameter block of the routine glp_write_mps() */
       int prob_info;
