@@ -2197,6 +2197,155 @@ void glp_set_row_name(LPI *lp, int i, char *name)
       return;
 }
 
+/*----------------------------------------------------------------------
+-- glp_to_lpx - convert LP problem instance to low-level object.
+--
+-- *Synopsis*
+--
+-- #include "glpk.h"
+-- void *glp_to_lpx(LPI *lpi, int all);
+--
+-- *Description*
+--
+-- The routine glp_to_lpx converts the LP problem instance, which the
+-- parameter lpi points to, to an low-level LP problem object.
+--
+-- If the flag all is set, the routine also copies all symbolic names
+-- to the low-level object. Otherwise no symbolic names are copied.
+--
+-- *Returns*
+--
+-- The routine glp_to_lpx returns a pointer to the created low-level
+-- object. */
+
+void *glp_to_lpx(LPI *lpi, int all)
+{     LPX *lpx;
+      int m = glp_get_num_rows(lpi);
+      int n = glp_get_num_cols(lpi);
+      int i, j, k, typx, tagx, len, *rn;
+      double lb, ub, *aj;
+      /* create low-level LP problem object */
+      lpx = lpx_create_prob();
+      lpx_add_rows(lpx, m);
+      lpx_add_cols(lpx, n);
+      /* copy symbolic names (if req'd) */
+      if (all)
+      {  lpx_set_prob_name(lpx, glp_get_prob_name(lpi));
+         for (i = 1; i <= m; i++)
+            lpx_set_row_name(lpx, i, glp_get_row_name(lpi, i));
+         for (j = 1; j <= n; j++)
+            lpx_set_col_name(lpx, j, glp_get_col_name(lpi, j));
+      }
+      /* copy row scale factors */
+      for (i = 1; i <= m; i++)
+      {  lpx->rs[i] = glp_get_row_fctr(lpi, i);
+         insist(lpx->rs[i] > 0.0);
+      }
+      /* copy column scale factors */
+      for (j = 1; j <= n; j++)
+      {  lpx->rs[m+j] = glp_get_col_fctr(lpi, j);
+         insist(lpx->rs[m+j] > 0.0);
+      }
+      /* copy row bounds */
+      for (i = 1; i <= m; i++)
+      {  glp_get_row_bnds(lpi, i, &typx, &lb, &ub);
+         switch (typx)
+         {  case 'F': typx = LPX_FR; break;
+            case 'L': typx = LPX_LO; break;
+            case 'U': typx = LPX_UP; break;
+            case 'D': typx = LPX_DB; break;
+            case 'S': typx = LPX_FX; break;
+            default: insist(typx != typx);
+         }
+         lpx_set_row_bnds(lpx, i, typx, lb, ub);
+      }
+      /* copy column bounds */
+      for (j = 1; j <= n; j++)
+      {  glp_get_col_bnds(lpi, j, &typx, &lb, &ub);
+         switch (typx)
+         {  case 'F': typx = LPX_FR; break;
+            case 'L': typx = LPX_LO; break;
+            case 'U': typx = LPX_UP; break;
+            case 'D': typx = LPX_DB; break;
+            case 'S': typx = LPX_FX; break;
+            default: insist(typx != typx);
+         }
+         lpx_set_col_bnds(lpx, j, typx, lb, ub);
+      }
+      /* copy the objective function */
+      switch (glp_get_obj_sense(lpi))
+      {  case '-':
+            lpx_set_obj_dir(lpx, LPX_MIN);
+            break;
+         case '+':
+            lpx_set_obj_dir(lpx, LPX_MAX);
+            break;
+         default:
+            insist(lpi != lpi);
+      }
+      lpx_set_obj_c0(lpx, glp_get_obj_coef(lpi, 0));
+      for (j = 1; j <= n; j++)
+         lpx_set_col_coef(lpx, j, glp_get_obj_coef(lpi, j));
+      /* copy the constraint matrix */
+      rn = ucalloc(1+m, sizeof(int));
+      aj = ucalloc(1+m, sizeof(double));
+      for (j = 1; j <= n; j++)
+      {  len = glp_get_col_coef(lpi, j, rn, aj);
+         /* remove zero coefficients */
+         k = 1;
+         while (k <= len)
+         {  if (aj[k] == 0.0)
+            {  rn[k] = rn[len];
+               aj[k] = aj[len];
+               len--;
+            }
+            else
+               k++;
+         }
+         lpx_set_mat_col(lpx, j, len, rn, aj);
+      }
+      ufree(rn);
+      ufree(aj);
+      /* copy the basis information */
+      for (k = 1; k <= m+n; k++)
+      {  if (k <= m)
+            glp_get_row_soln(lpi, k, &tagx, NULL, NULL);
+         else
+            glp_get_col_soln(lpi, k-m, &tagx, NULL, NULL);
+         if (tagx == 'B')
+            lpx->tagx[k] = LPX_BS;
+         else
+         {  switch (lpx->typx[k])
+            {  case LPX_FR:
+                  lpx->tagx[k] = LPX_NF; break;
+               case LPX_LO:
+                  lpx->tagx[k] = LPX_NL; break;
+               case LPX_UP:
+                  lpx->tagx[k] = LPX_NU; break;
+               case LPX_DB:
+                  switch (tagx)
+                  {  case 'L':
+                        lpx->tagx[k] = LPX_NL; break;
+                     case 'U':
+                        lpx->tagx[k] = LPX_NU; break;
+                     default:
+                        if (fabs(lpx->lb[k]) <= fabs(lpx->ub[k]))
+                           lpx->tagx[k] = LPX_NL;
+                        else
+                           lpx->tagx[k] = LPX_NU;
+                        break;
+                  }
+                  break;
+               case LPX_FX:
+                  lpx->tagx[k] = LPX_NS; break;
+               default:
+                  insist(lpx->typx != lpx->typx);
+            }
+         }
+      }
+      return lpx;
+}
+
 /*----------------------------------------------------------------------
 -- glp_init_wmps - initialize parameter block by default values.
 --
