@@ -324,8 +324,8 @@ void inv_ftran(INV *inv, double x[], int save)
 -- given vector using the factorization of the basis matrix.
 --
 -- In order to perform BTRAN the routine solves the system B'*x' = x,
--- where B' is a matrix transposed to the basis matrix B, z' is vector
--- of unknowns (transformed vector that should be computed), z is vector
+-- where B' is a matrix transposed to the basis matrix B, x' is vector
+-- of unknowns (transformed vector that should be computed), x is vector
 -- of right-hand sides (input vector that should be transformed).
 --
 -- On entry the array x should contain components of the vector x in
